## Plan Update

We got stuck on a test and need to update the plan. We have just updated the hypothesis, and now have an opportunity to reflect and update the state of the plan based on our results.

### Updating or Completing the Plan

Based on the results thus far, you need to update the state of the plan. You can either:
- Mark the plan as `complete` if the existing hypothesis results can answer the initial question(s) we set out to answer.
- Mark the plan as `failed` if we are unable to answer the initial question(s) and the current team composition or team member failures prevent us from continuing our work.
  - Here, you should consider whether any remaining `unverified` hypotheses can still be tested given our current state.
- Mark the plan as `in_progress` if we're not ready to answer the initial question(s) yet, but you still believe that progress can be made on this or other hypotheses. In this case, you may need to add additional hypotheses to the plan.

### Adding New Hypotheses

If there are no remaining `unverified` hypotheses, and you believe, given the current state of the plan, that we can still make progress, then you need to propose some new hypotheses to add to the plan.

### Tips

- We can't interact with the physical world, and you're basically limited to whatever functionality your team members have. Keep this in mind when you are adding new hypotheses.
- Be sure to consider your team member's descriptions. Unless explicitly mentioned, they cannot perform arbitrary tasks and are limited to the functionality provided in their descriptions.
- If any of your new hypotheses required functionality not obviously available to your team members, you should fail the plan.
